==> mozc-1.3.931.102.tar.bz2: mozc-1.3.931.102/rewriter/remove_redundant_candidate_rewriter.h <==
// Copyright 2010-2011, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// This rewrite removes candidates if a segment have only a redundant candidate.
// Here, a redundant candidate means the candidate with same value
// as a segment key.

#ifndef MOZC_REWRITER_REMOVE_REDUNDANT_CANDIDATE_REWRITER_H_
#define MOZC_REWRITER_REMOVE_REDUNDANT_CANDIDATE_REWRITER_H_

#include "rewriter/rewriter_interface.h"

namespace mozc {

class Segments;

class RemoveRedundantCandidateRewriter : public RewriterInterface {
 public:
  RemoveRedundantCandidateRewriter();
  virtual ~RemoveRedundantCandidateRewriter();

  bool Rewrite(Segments *segments) const;

  int capability() const;
};
}  // namespace mozc
#endif  // MOZC_REWRITER_REMOVE_REDUNDANT_CANDIDATE_REWRITER_H_

==> mozc_1.11.1522.102.orig.tar.bz2: mozc-1.11.1522.102/rewriter/remove_redundant_candidate_rewriter.h <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// This rewrite removes candidates if a segment have only a redundant candidate.
// Here, a redundant candidate means the candidate with same value
// as a segment key.

#ifndef MOZC_REWRITER_REMOVE_REDUNDANT_CANDIDATE_REWRITER_H_
#define MOZC_REWRITER_REMOVE_REDUNDANT_CANDIDATE_REWRITER_H_

#include "rewriter/rewriter_interface.h"

namespace mozc {

class ConversionRequest;
class Segments;

class RemoveRedundantCandidateRewriter : public RewriterInterface {
 public:
  RemoveRedundantCandidateRewriter();
  virtual ~RemoveRedundantCandidateRewriter();

  virtual bool Rewrite(const ConversionRequest &request,
                       Segments *segments) const;

  int capability(const ConversionRequest &request) const;
};

}  // namespace mozc
#endif  // MOZC_REWRITER_REMOVE_REDUNDANT_CANDIDATE_REWRITER_H_
